==> nextcloud-app-news-1%3A25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ka_GE.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "მოთხოვნა არ შედგა, ქსელთან კავშირი ხელმიუწვდომელია!",
    "Request unauthorized. Are you logged in?" : "მოთხოვნა არაა ავტორიზირებული. გავლილი გაქვთ ავტორიზაცია?",
    "Token expired or app not enabled! Reload the page!" : "ტოკენს ამოეწურა ვადა ან აპლიკაცია არაა მოქმედი! გადატვირთეთ გვერდი! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "შიდა სერვერის შეცდომა! დამატებიტი ინფორმაციისთვის გთხოვთ შეამოწმოთ თქვენი data/nextcloud.log ფაილი.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "მოთხოვნა არ შედგა, Nextcloud ახლა სარემონტო რეჟიმშია!",
    "Unread articles" : "წაუკითხავი არტიკლები",
    "News" : "სიახლეები",
    "Shared with me" : "გაზიარებულია ჩემთან",
    "Download" : "ჩამოტვირთვა",
    "Close" : "დახურვა",
    "Web address" : "Web მისამართი",
    "No folder" : "დირექტორია არაა",
    "Folder name" : "დირექტორიის სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "Feed exists already!" : "ლენტა უკვე არსებობს!",
    "New folder" : "ახალი დირექტორია",
    "Folder exists already!" : "დირექტორია უკვე არსებობს!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ძირითადი აუტენტიფიკაციის მონაცემები არ უნდა იყოს დაშიფრული! სერვერთან ან მონაცემთა ბაზის წვდომის უფლებებით ყველა შეძლებს მათ ნახვას.",
    "Credentials" : "უფლებამოსილებები",
    "Subscribe" : "გამოწერა",
    "Maximum read count per feed" : "თითო ლენტაზე მაქისმალური კითხვის რაოდენობა",
    "Maximum redirects" : " მაქს. გადამისამართებები",
    "Feed fetcher timeout" : "ლენტის მომპოვებლის დროის ამოწურვა",
    "Explore Service URL" : "სერვის მისამართის დათვალიერება",
    "Use system cron for updates" : "განახლებისთვის გამოიყენეთ სისტემური კრონი",
    "Move" : "გადატანა",
    "Share" : "გაზიარება",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "All articles" : "ყველა არტიკლი",
    "Starred" : "ვარსკვლავმინიჭებული",
    "Explore" : "მიმოხილვა",
    "Settings" : "პარამეტრები",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Disable mark read through scrolling" : "გადახვევით წაკითხულად ქცევის გათიშვა",
    "Show all articles" : "ყველა არტიკლის ჩვენება",
    "Reverse ordering (oldest on top)" : "უკუგანლაგება (ძველები ზემოთ)",
    "Default" : "საწყისი პარამეტრები",
    "Rename" : "გადარქმევა",
    "Delete" : "გაუქმება",
    "Rename Feed" : "ლენტის სახელის ცვლილება",
    "Unpin from top" : "ზევიდან ამოღება",
    "Pin to top" : "ზევით დამატება",
    "Newest first" : "ჯერ ახლები",
    "Oldest first" : "ჯერ ძველები",
    "Default order" : "საწყისი განლაგება",
    "Enable full text" : "სრული ტექსტის ამოქმედება",
    "Disable full text" : "სრული ტექსტის გათიშვა",
    "Unread updated" : "განახლებულის წაუკითხავად მონიშვნა",
    "Ignore updated" : "განახლებულის იგნორირება",
    "Toggle star article" : "არტიკლის ვარსკლავის გადართვა",
    "Close details" : "დეტალების დახურვა",
    "by" : "მიერ",
    "from" : "დან",
    "Play audio" : "აუდიოს დაკვრა",
    "Download audio" : "აუდიოს ჩამოტვირთვა",
    "Download video" : "ვიდეოს ჩამოტვირთვა",
    "Open website" : "ვებ-საიტის გახსნა",
    "Keep article unread" : "დატოვეთ არტიკლი წაუკითხავი",
    "Toggle keep current article unread" : "გადართეთ არტიკლის წაუკთხავად დატოვება",
    "Remove keep article unread" : "მოაშორეთ არტიკლს წაუკითხავად დატოვება",
    "Title" : "სათაური",
    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
    "Action" : "ქმედება",
    "Jump to next article" : "შემდეგ არტიკლზე გადასვლა",
    "Jump to previous article" : "წინა არტიკლზე გადასვლა",
    "right" : "მარჯვნივ",
    "left" : "მარცხნივ",
    "Star article and jump to next one" : "მიეცით არტიკლს ვარსკლავი და გადადით შემდეგზე",
    "Open article in new tab" : "არტიკლის ახალ ტაბში გახნსა",
    "Refresh" : "განახლება",
    "Load next feed" : "შემდეგი ლენტის ჩატვირთვა",
    "Load previous feed" : "წინა ლენტის ჩატვირთვა",
    "Load previous folder" : "წინა დირექტორიის ჩატვირთვა",
    "Load next folder" : "შემდეგი დირექტორიის ჩატვირთვა",
    "Scroll to active navigation entry" : "ჩამოწიეთ აქტიური ნავიგაციის შენატანისკენ",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "არჩეულია Ajax-ის ან webcron-ის რეჟიმი! თქვენი ლენტა არ განახლდება!",
    "How to set up the operating system cron" : "როგორ დავაყენოთ ოპერაციული სისტემის კრონი",
    "Install and set up a faster parallel updater that uses the News app's update API" : "დააყენეთ და მოაწყვეთ უფრო სწრაფი პარალელური განახლება რომელიც მოიხმარს სიახლეების აპლიკაციის განახლების პროგრამულ ინტერფეისს",
    "No articles available" : "არტიკლები ხელმიუწვდომელია",
    "No unread articles available" : "წაუკითხავი არტიკლები არაა",
    "Star article" : "არტიკლის ვარსკლავით შეფასება",
    "Unstar article" : "მოხსენით არტიკლს ვარსკლავი",
    "Description" : "გვერდის დახასიათება",
    "Toggle expand article in compact view" : "გადართეთ არტიკლის განვრცობა კომპაქტურ ხედში",
    "Mark current article's feed/folder read" : "მონიშნეთ ამ არტიკლის ლენტა/დირექტორია წაკითხულად",
    "Folder" : "დირექტორია",
    "Go back" : "უკან დაბრუნება",
    "New Folder" : "ახალი დირექტორია",
    "Create" : "შექმნა",
    "Update failed more than 50 times" : "განახლება 50-ზე მეტჯერ დასრულდა წარუმატებლად",
    "Deleted feed" : "ლენტის გაუქმება",
    "Undo delete feed" : "ლენტის გაუქმების უკუგდება",
    "Menu" : "მენიუ",
    "Open feed URL" : "ლენტის URL-ს გახსნა",
    "Dismiss" : "დათხოვნა",
    "Collapse" : "აკეცვა",
    "Deleted folder" : "დირექტორიის გაუქმება",
    "Undo delete folder" : "დირექტორიის გაუქმების უკუგდება",
    "Compact view" : "კომპაქტური ხედი",
    "Expand articles on key navigation" : "კლავიშის ნავიგაციისას არტიკლის განვრცობა",
    "Subscriptions (OPML)" : "გამოწერები (OPML)",
    "Import" : "იმპორტი",
    "Export" : "ექსპორტი",
    "Error when importing: File does not contain valid OPML" : "შეცდომა იმპორტირების დროს: ფაილი არ შეიცავს მართებულ OPML-ს",
    "Error when importing: OPML is does neither contain feeds nor folders" : "შეცდომა იმპორტირების დროს: OPML არც ლენტას მოიცავს და არც დირექტორიებს",
    "Unread/Starred Articles" : "წაუკითხავი/ვარსკლავიანი არტიკლები",
    "Error when importing: file does not contain valid JSON" : "შეცდომა იმპორტირებისას: ფაილი არ შეიცავს მართებულ JSON–ს",
    "Help" : "დახმარება",
    "Documentation" : "დოკუმენტაცია",
    "Report a bug" : "განაცხადეთ შეცდომა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-news-1%3A28.0.0rc.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ka_GE.js <==
OC.L10N.register(
    "news",
    {
    "News" : "სიახლეები",
    "%1$s shared \"%2$s\" with you" : "%1$s-სგან გაგიზიარდათ \"%2$s\"",
    "Unread articles" : "წაუკითხავი არტიკლები",
    "Shared with me" : "გაზიარებულია ჩემთან",
    "Download" : "ჩამოტვირთვა",
    "Close" : "დახურვა",
    "Web address" : "Web მისამართი",
    "No folder" : "დირექტორია არაა",
    "Folder name" : "დირექტორიის სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "Feed exists already!" : "ლენტა უკვე არსებობს!",
    "New folder" : "ახალი დირექტორია",
    "Folder exists already!" : "დირექტორია უკვე არსებობს!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ძირითადი აუტენტიფიკაციის მონაცემები არ უნდა იყოს დაშიფრული! სერვერთან ან მონაცემთა ბაზის წვდომის უფლებებით ყველა შეძლებს მათ ნახვას.",
    "Credentials" : "უფლებამოსილებები",
    "Subscribe" : "გამოწერა",
    "Maximum read count per feed" : "თითო ლენტაზე მაქისმალური კითხვის რაოდენობა",
    "Maximum redirects" : " მაქს. გადამისამართებები",
    "Feed fetcher timeout" : "ლენტის მომპოვებლის დროის ამოწურვა",
    "Explore Service URL" : "სერვის მისამართის დათვალიერება",
    "Use system cron for updates" : "განახლებისთვის გამოიყენეთ სისტემური კრონი",
    "Show all articles" : "ყველა არტიკლის ჩვენება",
    "Move" : "გადატანა",
    "Share" : "გაზიარება",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "All articles" : "ყველა არტიკლი",
    "Starred" : "ვარსკვლავმინიჭებული",
    "Explore" : "მიმოხილვა",
    "Rename" : "გადარქმევა",
    "Delete" : "გაუქმება",
    "Rename Feed" : "ლენტის სახელის ცვლილება",
    "Unpin from top" : "ზევიდან ამოღება",
    "Pin to top" : "ზევით დამატება",
    "Newest first" : "ჯერ ახლები",
    "Oldest first" : "ჯერ ძველები",
    "Default order" : "საწყისი განლაგება",
    "Enable full text" : "სრული ტექსტის ამოქმედება",
    "Disable full text" : "სრული ტექსტის გათიშვა",
    "Toggle star article" : "არტიკლის ვარსკლავის გადართვა",
    "Close details" : "დეტალების დახურვა",
    "by" : "მიერ",
    "Play audio" : "აუდიოს დაკვრა",
    "Download audio" : "აუდიოს ჩამოტვირთვა",
    "Download video" : "ვიდეოს ჩამოტვირთვა",
    "Open website" : "ვებ-საიტის გახსნა",
    "Keep article unread" : "დატოვეთ არტიკლი წაუკითხავი",
    "Toggle keep current article unread" : "გადართეთ არტიკლის წაუკთხავად დატოვება",
    "Remove keep article unread" : "მოაშორეთ არტიკლს წაუკითხავად დატოვება",
    "Default" : "საწყისი პარამეტრები",
    "General" : "ზოგადი",
    "Disable mark read through scrolling" : "გადახვევით წაკითხულად ქცევის გათიშვა",
    "Reverse ordering (oldest on top)" : "უკუგანლაგება (ძველები ზემოთ)",
    "Import" : "იმპორტი",
    "Export" : "ექსპორტი",
    "Please wait" : "გთხოვთ მოითმინოთ",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Refresh" : "განახლება",
    "Jump to previous article" : "წინა არტიკლზე გადასვლა",
    "Jump to next article" : "შემდეგ არტიკლზე გადასვლა",
    "Open article in new tab" : "არტიკლის ახალ ტაბში გახნსა",
    "Resources" : "რესურსები",
    "Title" : "სათაური",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "არჩეულია Ajax-ის ან webcron-ის რეჟიმი! თქვენი ლენტა არ განახლდება!",
    "How to set up the operating system cron" : "როგორ დავაყენოთ ოპერაციული სისტემის კრონი",
    "Install and set up a faster parallel updater that uses the News app's update API" : "დააყენეთ და მოაწყვეთ უფრო სწრაფი პარალელური განახლება რომელიც მოიხმარს სიახლეების აპლიკაციის განახლების პროგრამულ ინტერფეისს"
},
"nplurals=2; plural=(n!=1);");
